@@ -1,5 +1,9 @@
 assertthat::on_failure(is_valid_bdc) <- function (call, env) {
-  paste0(deparse(call$bdc), " is not a valid business day convention.")
+  paste0(deparse(call$bdc), " contains invalid business day convention.")
+}
+
+assertthat::on_failure(is_valid_day_basis) <- function(call, env) {
+  paste0(deparse(call$bdc), " contains invalid business day convention.")
 }
 
 assertthat::on_failure(is_list_of) <- function(call, env) {
